@@ -36,8 +36,8 @@ class ArtifactEntry:
         assert_that(local_root_path).is_not_none()
         assert_that(artifact_id).is_not_none()
 
-        local_path = f"{local_root_path}/{self.path}"
-        i_last_separator = len(local_path) - local_path[::-1].find("/") - 1
+        local_path = os.path.join(local_root_path, self.path)
+        i_last_separator = len(local_path) - local_path[::-1].find(os.path.sep) - 1
         Path(local_path[:i_last_separator]).mkdir(parents=True, exist_ok=True)
 
         interface.download_file(self.path, artifact_id, local_path)
@@ -98,7 +98,7 @@ class Artifact:
                     path = local_path[i_name_begin:]
                 else:
                     # add시 name이 지정되지 않은 경우: 하위폴더명/파일명
-                    path = os.path.join(*local_path.split("/")[2:])
+                    path = os.path.join(*local_path.split(os.path.sep)[2:])
                 size = os.stat(local_path).st_size
                 with open(local_path,"rb") as f:
                     digest = hashlib.md5(f.read()).hexdigest()
@@ -133,7 +133,7 @@ class Artifact:
         # artifact에 추가된 파일들(ArtifactEntry의 파일)은 각각의 upload함수 호출
         for i, entry in enumerate(self.entry_list):
             # ArtifactEntry.upload() 호출시 인자로서 파일이 저장될 폴더 정보를 넘겨줌
-            root_path = f"{run.run_id}/artifact/{self.type}/{self.name}"
+            root_path = os.path.join(str(run.run_id), "artifact", self.type, self.name)
             last_file_yn = "Y" if i == len(self.entry_list)-1 else "N"
             succeeded = entry.upload(root_path, run.run_id, self.id, last_file_yn, artifact_digest, entry_list)
             if not succeeded:
@@ -143,7 +143,7 @@ class Artifact:
     # Artifact 객체를 기반으로 Artifact에 등록된 모든 엔트리의 다운로드 수행
     def download(self) -> str:
         # ./deepdriver/artifact/{artifact_id}/ 폴더가 생성된다
-        local_root_path = f"./deepdriver/artifact/{self.id}"
+        local_root_path = os.path.join(".", "deepdriver", "artifact", str(self.id))
 
         # Artifact 객체가 가진 entry_list 의  ArtifactEntry.download()를 각각 호출
         for entry in self.entry_list:
